##  Editing Relations
You can update a single relation or edit multiple relations at the same time.
### Single Relation
  1. Hover over the relation and choose Edit.
  2. Edit any information needed.
  3. Click Save or use the Save & Next button to move automatically to the next section.


### Multiple Relations
  1. Hover over the section where you want to edit relations.
  2. From the three-dot menu, choose Edit multiple to open a dialog with selection options.
  3. Select the relations you want to edit.
  4. Choose Use Selected Fact Sheets.
  5. Edit any information as needed.
  6. Click Save or use the Save & Next button to move automatically to the next section.
